@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Params::CheckCompiler qw( compile );
 use WebService::PivotalTracker::Comment;
@@ -101,8 +101,11 @@ with 'WebService::PivotalTracker::Entity';
 {
     my $check = compile(
         params => {
-            person_id => { type => PositiveInt },
-            text      => { type => NonEmptyStr },
+            person_id => {
+                type     => PositiveInt,
+                optional => 1,
+            },
+            text => { type => NonEmptyStr },
         }
     );
 
@@ -219,15 +222,15 @@ sub _labels_uri {
     return $self->_client->build_uri($path);
 }
 
-## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _self_uri {
     my $self = shift;
 
-    return sprintf(
-        '/stories/%s',
-        $self->id,
+    return $self->_client->build_uri(
+        sprintf(
+            '/stories/%s',
+            $self->id,
+        )
     );
 }
-## use critic
 
 1;
